==> snipe-it-6.3.0.zip: snipe-it-6.3.0/resources/lang/pl-PL/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Potwierdź zbiorcze usuwanie aktywów',
    'bulk_restore'      => 'Potwierdzenie masowego przywracania zasobów', 
  'bulk_delete_help'	=> 'Przejrzyj usuwanie zbiorcze aktywów poniżej. Po usunięciu tych aktywów będą one mogły zostać przywrócone, ale nie będą one skojarzone z żadnym z użytkowników, do których są aktualnie przypisane.',
  'bulk_restore_help'	=> 'Przejrzyj poniższą listę zasobów masowego przywracania. Po przywrócenie zasoby nie będą powiązane z użytkownikami, do których były wcześniej przypisane.',
  'bulk_delete_warn'	=> 'Zamierzasz usunąć :asset_count aktywów.',
  'bulk_restore_warn'	=> 'Zamierzasz przywrócić :asset_count aktywów.',
    'bulk_update'		=> 'Zbiorcza aktualizacja aktywów',
    'bulk_update_help'	=> 'Ten formularz umożliwia zbiorczą aktualizację wielu aktywów na raz. Wypełnij tylko te pola, które chcesz zmienić. Puste pola pozostaną niezmienione. ',
    'bulk_update_warn'	=> 'Zamierzasz edytować właściwości pojedynczego zasobu.|Zamierzasz edytować właściwości :asset_count zasobów.',
    'bulk_update_with_custom_field' => 'Zauważ, że aktywa są :asset_model_count różne typy modeli.',
    'bulk_update_model_prefix' => 'Na modelach', 
    'bulk_update_custom_field_unique' => 'To pole jest unikalne i nie może być edytowane zbiorczo.',
    'checkedout_to'		=> 'Wypożyczony do',
    'checkout_date'		=> 'Data przypisania',
    'checkin_date'		=> 'Data przypisania',
    'checkout_to'		=> 'Przypisane do',
    'cost'				=> 'Koszt zakupu',
    'create'			=> 'Nowy nabytek',
    'date'				=> 'Data zakupu',
    'depreciation'	    => 'Deprecjacja',
    'depreciates_on'	=> 'Amortyzacja włączona',
    'default_location'	=> 'Domyślna lokalizacja',
    'default_location_phone' => 'Domyślny telefon lokalizacji',
    'eol_date'			=> 'Data końca licencji',
    'eol_rate'			=> 'Szacowany koniec licencji',
    'expected_checkin'  => 'Przewidywana data przyjęcia',
    'expires'			=> 'Wygasa',
    'fully_depreciated'	=> 'W pełni zamortyzowany',
    'help_checkout'		=> 'Jeśli chcesz natychmiast przypisać ten zasób, wybierz "Gotowy do wdrożęnia" z powyższej listy stanu. ',
    'mac_address'		=> 'Adres MAC',
    'manufacturer'		=> 'Producent',
    'model'				=> 'Model',
    'months'			=> 'miesiąc',
    'name'				=> 'Nazwa nabytku',
    'notes'				=> 'Notatki',
    'order'				=> 'Numer zamówienia',
    'qr'				=> 'Kod QR',
    'requestable'		=> 'Użytkownicy mogą wymagać tego zasobu',
    'select_statustype'	=> 'Wybierz status',
    'serial'			=> 'Numer seryjny',
    'status'			=> 'Status',
    'tag'				=> 'Tag-i zasobu/nabytku',
    'update'			=> 'Aktualizacja zasobu/nabytku',
    'warranty'			=> 'Gwarancja',
        'warranty_expires'		=> 'Gwarancja wygasa',
    'years'				=> 'rok',
    'asset_location' => 'Zaktualizuj lokalizację aktywa',
    'asset_location_update_default_current' => 'Zaktualizuj domyślną i aktualną lokalizację',
    'asset_location_update_default' => 'Zaktualizuj tylko domyślną lokalizację',
    'asset_location_update_actual' => 'Aktualizuj tylko bieżącą lokalizację',
    'asset_not_deployable' => 'Ten status oznacza brak możliwości wdrożenia. Ten zasób nie może zostać przypisany.',
    'asset_deployable' => 'Ten status oznacza możliwość wdrożenia. Ten zasób może zostać przypisany.',
    'processing_spinner' => 'Przetwarzanie... (To może zająć trochę czasu dla dużych plików)',
    'optional_infos'  => 'Informacje opcjonalne',
    'order_details'   => 'Informacje związane z zamówieniem'
];

==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/pl-PL/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Potwierdź zbiorcze usuwanie aktywów',
    'bulk_restore'      => 'Potwierdzenie masowego przywracania zasobów', 
  'bulk_delete_help'	=> 'Przejrzyj usuwanie zbiorcze aktywów poniżej. Po usunięciu tych aktywów będą one mogły zostać przywrócone, ale nie będą one skojarzone z żadnym z użytkowników, do których są aktualnie przypisane.',
  'bulk_restore_help'	=> 'Przejrzyj poniższą listę zasobów masowego przywracania. Po przywrócenie zasoby nie będą powiązane z użytkownikami, do których były wcześniej przypisane.',
  'bulk_delete_warn'	=> 'Zamierzasz usunąć :asset_count aktywów.',
  'bulk_restore_warn'	=> 'Zamierzasz przywrócić :asset_count aktywów.',
    'bulk_update'		=> 'Zbiorcza aktualizacja aktywów',
    'bulk_update_help'	=> 'Ten formularz umożliwia zbiorczą aktualizację wielu aktywów na raz. Wypełnij tylko te pola, które chcesz zmienić. Puste pola pozostaną niezmienione. ',
    'bulk_update_warn'	=> 'Zamierzasz edytować właściwości pojedynczego zasobu.|Zamierzasz edytować właściwości :asset_count zasobów.',
    'bulk_update_with_custom_field' => 'Zauważ, że aktywa są :asset_model_count różne typy modeli.',
    'bulk_update_model_prefix' => 'Na modelach', 
    'bulk_update_custom_field_unique' => 'To pole jest unikalne i nie może być edytowane zbiorczo.',
    'checkedout_to'		=> 'Wypożyczony do',
    'checkout_date'		=> 'Data przypisania',
    'checkin_date'		=> 'Data przypisania',
    'checkout_to'		=> 'Przypisane do',
    'cost'				=> 'Koszt zakupu',
    'create'			=> 'Nowy nabytek',
    'date'				=> 'Data zakupu',
    'depreciation'	    => 'Deprecjacja',
    'depreciates_on'	=> 'Amortyzacja włączona',
    'default_location'	=> 'Domyślna lokalizacja',
    'default_location_phone' => 'Domyślny telefon lokalizacji',
    'eol_date'			=> 'Data końca licencji',
    'eol_rate'			=> 'Szacowany koniec licencji',
    'expected_checkin'  => 'Przewidywana data przyjęcia',
    'expires'			=> 'Wygasa',
    'fully_depreciated'	=> 'W pełni zamortyzowany',
    'help_checkout'		=> 'Jeśli chcesz natychmiast przypisać ten zasób, wybierz "Gotowy do wdrożęnia" z powyższej listy stanu. ',
    'mac_address'		=> 'Adres MAC',
    'manufacturer'		=> 'Producent',
    'model'				=> 'Model',
    'months'			=> 'miesiąc',
    'name'				=> 'Nazwa nabytku',
    'notes'				=> 'Notatki',
    'order'				=> 'Numer zamówienia',
    'qr'				=> 'Kod QR',
    'requestable'		=> 'Użytkownicy mogą wymagać tego zasobu',
    'redirect_to_all'   => 'Wróć do wszystkich :type',
    'redirect_to_type'   => 'Przejdź do :type',
    'redirect_to_checked_out_to'   => 'Go to Checked Out to',
    'select_statustype'	=> 'Wybierz status',
    'serial'			=> 'Numer seryjny',
    'status'			=> 'Status',
    'tag'				=> 'Tag-i zasobu/nabytku',
    'update'			=> 'Aktualizacja zasobu/nabytku',
    'warranty'			=> 'Gwarancja',
        'warranty_expires'		=> 'Gwarancja wygasa',
    'years'				=> 'rok',
    'asset_location' => 'Zaktualizuj lokalizację aktywa',
    'asset_location_update_default_current' => 'Zaktualizuj domyślną i aktualną lokalizację',
    'asset_location_update_default' => 'Zaktualizuj tylko domyślną lokalizację',
    'asset_location_update_actual' => 'Aktualizuj tylko bieżącą lokalizację',
    'asset_not_deployable' => 'Ten status oznacza brak możliwości wdrożenia. Ten zasób nie może zostać przypisany.',
    'asset_deployable' => 'Ten status oznacza możliwość wdrożenia. Ten zasób może zostać przypisany.',
    'processing_spinner' => 'Przetwarzanie... (To może zająć trochę czasu dla dużych plików)',
    'optional_infos'  => 'Informacje opcjonalne',
    'order_details'   => 'Informacje związane z zamówieniem'
];
